======
pyrish
======


.. image:: https://img.shields.io/badge/license-MIT-blue.svg?style=flat-square
     :target: https://github.com/DhiaTN/pyrish/blob/master/LICENSE
     :alt: Project Licence

.. image:: https://img.shields.io/travis/DhiaTN/pyrish/master.svg?style=flat-square
     :target: https://travis-ci.org/DhiaTN/pyrish
     :alt: Builds

.. image:: https://img.shields.io/pypi/v/pyrish.svg?style=flat-square
     :target: https://pypi.python.org/pypi/pyrish/
     :alt: Version

.. image:: https://img.shields.io/pypi/pyversions/pyrish.svg?style=flat-square
     :target: https://pypi.python.org/pypi/pyrish
     :alt: Python version

.. image:: https://pyup.io/repos/github/DhiaTN/pyrish/shield.svg?style=flat-square
     :target: https://pyup.io/repos/github/DhiaTN/pyrish/
     :alt: Updates

------------------------------------------------------------------------------------------------

A growing collection of code and utility classes which I have refactored from apps I have written or have
found in the internet.


Get started
--------------

Installation::

    pip install pyrish
